diff --git a/src/wp-admin/includes/user.php b/src/wp-admin/includes/user.php
index 82d792fb3c..fb5352305a 100644
--- a/src/wp-admin/includes/user.php
+++ b/src/wp-admin/includes/user.php
@@ -630,6 +630,12 @@ function _wp_privacy_completed_request( $request_id ) {
 
 	update_post_meta( $request_id, '_wp_user_request_completed_timestamp', time() );
 
+	$status = 'request-skipped';
+
+	if ( get_post_status( $request_id ) === $status ) {
+		return;
+	}
+
 	$result = wp_update_post(
 		array(
 			'ID'          => $request_id,
@@ -687,6 +693,7 @@ function _wp_personal_data_handle_actions() {
 				$action_type               = sanitize_text_field( wp_unslash( $_POST['type_of_action'] ) );
 				$username_or_email_address = sanitize_text_field( wp_unslash( $_POST['username_or_email_for_privacy_request'] ) );
 				$email_address             = '';
+				$request_confirmation      = sanitize_text_field( $_POST['request_confirmation'] );
 
 				if ( ! in_array( $action_type, _wp_privacy_action_request_types(), true ) ) {
 					add_settings_error(
@@ -717,7 +724,7 @@ function _wp_personal_data_handle_actions() {
 					break;
 				}
 
-				$request_id = wp_create_user_request( $email_address, $action_type );
+				$request_id = wp_create_user_request( $email_address, $action_type, $request_confirmation );
 
 				if ( is_wp_error( $request_id ) ) {
 					add_settings_error(
@@ -737,7 +744,9 @@ function _wp_personal_data_handle_actions() {
 					break;
 				}
 
-				wp_send_user_request( $request_id );
+				if ( 'yes' === $request_confirmation ) {
+					wp_send_user_request( $request_id );
+				}
 
 				add_settings_error(
 					'username_or_email_for_privacy_request',
@@ -837,7 +846,11 @@ function _wp_personal_data_export_page() {
 			<div class="wp-privacy-request-form-field">
 				<label for="username_or_email_for_privacy_request"><?php esc_html_e( 'Username or email address' ); ?></label>
 				<input type="text" required class="regular-text" id="username_or_email_for_privacy_request" name="username_or_email_for_privacy_request" />
-				<?php submit_button( __( 'Send Request' ), 'secondary', 'submit', false ); ?>
+				<select name="request_confirmation">
+					<option value="yes"><?php _e( 'With Confirmation' ); ?></option>
+					<option value="no"><?php _e( 'Without Confirmation' ); ?></option>
+				</select>
+				<?php submit_button( __( 'Add Request' ), 'secondary', 'submit', false ); ?>
 			</div>
 			<?php wp_nonce_field( 'personal-data-request' ); ?>
 			<input type="hidden" name="action" value="add_export_personal_data_request" />
@@ -921,7 +934,11 @@ function _wp_personal_data_removal_page() {
 			<div class="wp-privacy-request-form-field">
 				<label for="username_or_email_for_privacy_request"><?php esc_html_e( 'Username or email address' ); ?></label>
 				<input type="text" required class="regular-text" id="username_or_email_for_privacy_request" name="username_or_email_for_privacy_request" />
-				<?php submit_button( __( 'Send Request' ), 'secondary', 'submit', false ); ?>
+				<select name="request_confirmation">
+					<option value="yes"><?php _e( 'With Confirmation' ); ?></option>
+					<option value="no"><?php _e( 'Without Confirmation' ); ?></option>
+				</select>
+				<?php submit_button( __( 'Add Request' ), 'secondary', 'submit', false ); ?>
 			</div>
 			<?php wp_nonce_field( 'personal-data-request' ); ?>
 			<input type="hidden" name="action" value="add_remove_personal_data_request" />
@@ -1384,6 +1401,9 @@ abstract class WP_Privacy_Requests_Table extends WP_List_Table {
 			case 'request-completed':
 				$timestamp = $item->completed_timestamp;
 				break;
+			case 'request-skipped':
+				$timestamp = $item->completed_timestamp;
+				break;
 		}
 
 		echo '<span class="status-label status-' . esc_attr( $status ) . '">';
@@ -1556,6 +1576,7 @@ class WP_Privacy_Data_Export_Requests_Table extends WP_Privacy_Requests_Table {
 				esc_html_e( 'Waiting for confirmation' );
 				break;
 			case 'request-confirmed':
+			case 'request-skipped':
 				/** This filter is documented in wp-admin/includes/ajax-actions.php */
 				$exporters       = apply_filters( 'wp_privacy_personal_data_exporters', array() );
 				$exporters_count = count( $exporters );
@@ -1678,6 +1699,7 @@ class WP_Privacy_Data_Removal_Requests_Table extends WP_Privacy_Requests_Table {
 				esc_html_e( 'Waiting for confirmation' );
 				break;
 			case 'request-confirmed':
+			case 'request-skipped':
 				/** This filter is documented in wp-admin/includes/ajax-actions.php */
 				$erasers       = apply_filters( 'wp_privacy_personal_data_erasers', array() );
 				$erasers_count = count( $erasers );
diff --git a/src/wp-includes/post.php b/src/wp-includes/post.php
index eb69ac727b..38591e4071 100644
--- a/src/wp-includes/post.php
+++ b/src/wp-includes/post.php
@@ -429,6 +429,16 @@ function create_initial_post_types() {
 			'exclude_from_search' => false,
 		)
 	);
+
+	register_post_status(
+		'request-skipped',
+		array(
+			'label'               => _x( 'Confirmation Skipped', 'request status' ),
+			'internal'            => true,
+			'_builtin'            => true, /* internal use only. */
+			'exclude_from_search' => false,
+		)
+	);
 }
 
 /**
diff --git a/src/wp-includes/user.php b/src/wp-includes/user.php
index 752b92dcde..1e49d1e1f3 100644
--- a/src/wp-includes/user.php
+++ b/src/wp-includes/user.php
@@ -3301,14 +3301,16 @@ function _wp_privacy_account_request_confirmed_message( $request_id ) {
  *
  * @since 4.9.6
  *
  * @param string $email_address User email address. This can be the address of a registered or non-registered user.
  * @param string $action_name   Name of the action that is being confirmed. Required.
  * @param array  $request_data  Misc data you want to send with the verification request and pass to the actions once the request is confirmed.
  * @return int|WP_Error Returns the request ID if successful, or a WP_Error object on failure.
  */
-function wp_create_user_request( $email_address = '', $action_name = '', $request_data = array() ) {
-	$email_address = sanitize_email( $email_address );
-	$action_name   = sanitize_key( $action_name );
+function wp_create_user_request( $email_address = '', $action_name = '', $request_confirmation = '', $request_data = array() ) {
+	$email_address        = sanitize_email( $email_address );
+	$action_name          = sanitize_key( $action_name );
+	$request_confirmation = sanitize_text_field( $request_confirmation );
 
 	if ( ! is_email( $email_address ) ) {
 		return new WP_Error( 'invalid_email', __( 'Invalid email address.' ) );
@@ -3339,13 +3341,19 @@ function wp_create_user_request( $email_address = '', $action_name = '', $reques
 		return new WP_Error( 'duplicate_request', __( 'An incomplete request for this email address already exists.' ) );
 	}
 
+	if ( 'yes' === $request_confirmation ) {
+		$status = 'request-pending';
+	} else {
+		$status = 'request-skipped';
+	}
+
 	$request_id = wp_insert_post(
 		array(
 			'post_author'   => $user_id,
 			'post_name'     => $action_name,
 			'post_title'    => $email_address,
 			'post_content'  => wp_json_encode( $request_data ),
-			'post_status'   => 'request-pending',
+			'post_status'   => $status,
 			'post_type'     => 'user_request',
 			'post_date'     => current_time( 'mysql', false ),
 			'post_date_gmt' => current_time( 'mysql', true ),
@@ -3301,14 +3301,16 @@ function _wp_privacy_account_request_confirmed_message( $request_id ) {
  * @since 4.9.6
  *
- * @param string $email_address User email address. This can be the address of a registered or non-registered user.
- * @param string $action_name   Name of the action that is being confirmed. Required.
- * @param array  $request_data  Misc data you want to send with the verification request and pass to the actions once the request is confirmed.
- * @return int|WP_Error Returns the request ID if successful, or a WP_Error object on failure.
+ * @param string $email_address        User email address. This can be the address of a registered or non-registered user.
+ * @param string $action_name          Name of the action that is being confirmed. Required.
+ * @param string $request_confirmation Option (yes/no) if the admins wants to send a confirmation e-mail to the user.
+ * @param array  $request_data         Misc data you want to send with the verification request and pass to the actions once the request is confirmed.
+ * @return int|WP_Error                Returns the request ID if successful, or a WP_Error object on failure.
  */
